ZeroAwareAllocator

Struct ZeroAwareAllocator 

pub struct ZeroAwareAllocator<A, L>{ /* private fields */ }
A memory allocator that keeps track of already-zeroed memory blocks.

This lets applications move zeroing off of the allocate_zeroed critical path. Instead they can, for example, bulk-zero memory blocks in the background before returning them to the allocator.

This allocator wraps an underinglying, inner allocator of type A, layering the bookkeeping of already-zeroed blocks on top of it.

Because this crate is no_std and does not assume the presence of an operating system, you must provide your own locking mechanism via the L type parameter. See the LockingMechanism trait for details.

Implementations

Source

impl<A, L> ZeroAwareAllocator<A, L>

pub const fn new(inner: A, lock: L) -> Self

Create a new ZeroAwareAllocator that wraps the given inner allocator.

pub fn inner(&self) -> &A

Get a shared reference to the inner allocator.

pub fn inner_mut(&mut self) -> &mut A

Get an exclusive reference to the inner allocator.

pub fn return_zeroed_memory_to_inner(&mut self)

Return all of the known-zeroed memory blocks to the underlying allocator.