pub struct ZeroAwareAllocator<A, L>where
A: Allocator,
L: LockingMechanism,{ /* private fields */ }Expand description
A memory allocator that keeps track of already-zeroed memory blocks.
This lets applications move zeroing off of the allocate_zeroed critical
path. Instead they can, for example, bulk-zero memory blocks in the
background before returning them to the allocator.
This allocator wraps an underinglying, inner allocator of type A, layering
the bookkeeping of already-zeroed blocks on top of it.
Because this crate is no_std and does not assume the presence of an
operating system, you must provide your own locking mechanism via the L
type parameter. See the LockingMechanism trait for details.
Implementations
Sourceimpl<A, L> ZeroAwareAllocator<A, L>where
A: Allocator,
L: LockingMechanism,
impl<A, L> ZeroAwareAllocator<A, L>where
A: Allocator,
L: LockingMechanism,
Sourcepub const fn new(inner: A, lock: L) -> Self
pub const fn new(inner: A, lock: L) -> Self
Create a new ZeroAwareAllocator that wraps the given inner
allocator.
Sourcepub fn return_zeroed_memory_to_inner(&mut self)
pub fn return_zeroed_memory_to_inner(&mut self)
Return all of the known-zeroed memory blocks to the underlying allocator.